@@ -52,11 +52,11 @@ descriptions = {
                                (_("toggle playlist mode"), _("toggle the playlist mode")),
           "playlistclear":     (_("clear"), _("clear playlist")),
           "playlistsave":      (_("save"), _("save playlist")),
-          "playlistload":      (_("load"), _("load playlist")),
           "showhelp":          (_("help"), _("show help")),
           "showlog":           (_("log"), _("show log messages")),
           "showstats":         (_("statistics"), _("show statistical information about database(s)")),
           "showiteminfolong":  (_("item info"), _("show information about selected item")),
+          "showlyrics":        (_("lyrics"), _("show lyrics of selected song")),
           "toggleiteminfowindow":  (_("toggle item info"), _("toggle information shown in item info window")),
           "togglelayout":      (_("toggle layout"), _("toggle layout")),
           "volumeup":          (_("volume up"), _("increase output volume")),
@@ -88,6 +88,7 @@ descriptions = {
           "search":            (_("search"), _("search entry")),
           "repeatsearch":      (_("repeat search"), _("repeat last search")),
           "rescan":            (_("rescan"), _("rescan/update id3 info for selection")),
+          "toggledelete":      (_("(un)delete"), _("delete/undelete selection ")),
           },
     "playlistwindow": {
           "selectnext":        (_("down"), _("move to the next entry")),
