@@ -57,7 +57,7 @@ class messagewin(window.window):
         if self.maxw<=80:
             width = self.maxw
         else:
-            width = 80 + int((self.maxw-80)*0.5)
+            width = 80 + int((self.maxw-80)*0.8)
         height = min(self._outputlen(width-2)+2, self.maxh-3)
         y = max(0, (self.maxh-height)/2)
         x = max(0, (self.maxw-width)/2)
@@ -129,7 +129,7 @@ class messagewin(window.window):
             sbar += statusbar.separator
             sbar += [(version.copyright, config.colors.statusbar.description)]
             sbar += statusbar.terminate
-            hub.notify(events.updatestatusbar(0, sbar))
+            hub.notify(events.statusbar_update(0, sbar))
 
     def update(self):
         window.window.update(self)
