@@ -19,6 +19,7 @@
 
 import os
 import fcntl
+import re
 import string
 import time
 
@@ -28,9 +29,10 @@ def makeNonBlocking(fd):
     fl = fcntl.fcntl(fd, fcntl.F_GETFL)
     fcntl.fcntl(fd, fcntl.F_SETFL, fl | os.O_NONBLOCK)
 
+startpattern = re.compile(r"^@R MPG123 *[-0-9a-zA-Z\s_]*$")
+
 class player(genericplayer):
-    def __init__(self, id, playlistid, autoplay,
-                 cmdline="/usr/bin/mpg321 --skip-printing-frames=5 -a /dev/dsp"):
+    def __init__(self, id, playlistid, autoplay, cmdline):
         self.cmdline = cmdline
         self.initmpg123()
         genericplayer.__init__(self, id, playlistid, autoplay)
@@ -38,7 +40,9 @@ class player(genericplayer):
     def initmpg123(self):
         """start new mpg123 process"""
         self.pstdin, self.pstdout = os.popen4(self.cmdline + " -R -")
-        assert self.pstdout.readline()=="@R MPG123\n", "Cannot initialize player"
+        startline = self.pstdout.readline()
+        if not re.match(startpattern, startline):
+            raise RuntimeError("cannot initialize player")
         makeNonBlocking(self.pstdout.fileno())
 
     def closempg123(self):
@@ -60,7 +64,6 @@ class player(genericplayer):
                 self.initmpg123()
                 self.playbackinfo.stopped()
                 self.pstdin.write("%s\n" % command)
-        
             else:
                 raise
 
@@ -83,17 +86,22 @@ class player(genericplayer):
             # alive
             self.sendmpg123("")
         elif r.startswith("@F"): 
-            pframes, lframes, ptime, ltime = string.split(r[3:])
+            pframes, lframes, ptime, ltime = string.split(r[3:])[:4]
             ptime = int(float(ptime))
             self.playbackinfo.updatetime(ptime)
         elif r.startswith("@P"):
             if self.playbackinfo.isplaying() and r[3]=="0":
                 self.playbackinfo.stopped()
                 self.requestnextsong()
+        elif r.startswith("@S"): 
+            ( version, layer, samplerate, mode, modeextension,
+              bytesperframe, channels, copyrighted, crcprotected, emphasis, bitrate ) = string.split(r[3:])[:11]
+            self.framespersecond = 1000.0 / 8 * int(bitrate) / int(bytesperframe)
                     
     def _playsong(self, song, manual):
         """play event.song next"""
         self.sendmpg123("L %s" % song.path)
+        self.framespersecond = None
         self.playbackinfo.updatesong(song)
 
     def _playerunpause(self):
@@ -114,6 +122,10 @@ class player(genericplayer):
             pass
         self.playbackinfo.paused()
 
+    def _playerseekrelative(self, seconds):
+        if self.framespersecond:
+            self.sendmpg123("J %+d" % int(seconds * self.framespersecond))
+
     def _playerstop(self):
         """stop playing"""
         self.sendmpg123("S")
@@ -126,6 +138,3 @@ class player(genericplayer):
     def _playerquit(self):
         self.sendmpg123("Q")
         self.closempg123()
-                    
-            
-
